# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..gtract import gtractInvertBSplineTransform


def test_gtractInvertBSplineTransform_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        inputReferenceVolume=dict(argstr="--inputReferenceVolume %s", extensions=None,),
        inputTransform=dict(argstr="--inputTransform %s", extensions=None,),
        landmarkDensity=dict(argstr="--landmarkDensity %s", sep=",",),
        numberOfThreads=dict(argstr="--numberOfThreads %d",),
        outputTransform=dict(argstr="--outputTransform %s", hash_files=False,),
    )
    inputs = gtractInvertBSplineTransform.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_gtractInvertBSplineTransform_outputs():
    output_map = dict(outputTransform=dict(extensions=None,),)
    outputs = gtractInvertBSplineTransform.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value
