# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import ROIStats


def test_ROIStats_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        debug=dict(argstr="-debug",),
        environ=dict(nohash=True, usedefault=True,),
        format1D=dict(argstr="-1Dformat", xor=["format1DR"],),
        format1DR=dict(argstr="-1DRformat", xor=["format1D"],),
        in_file=dict(argstr="%s", extensions=None, mandatory=True, position=-2,),
        mask=dict(
            argstr="-mask %s",
            deprecated="1.1.4",
            extensions=None,
            new_name="mask_file",
            position=3,
        ),
        mask_f2short=dict(argstr="-mask_f2short",),
        mask_file=dict(argstr="-mask %s", extensions=None,),
        nobriklab=dict(argstr="-nobriklab",),
        nomeanout=dict(argstr="-nomeanout",),
        num_roi=dict(argstr="-numroi %s",),
        out_file=dict(
            argstr="> %s",
            extensions=None,
            keep_extension=False,
            name_source="in_file",
            name_template="%s_roistat.1D",
            position=-1,
        ),
        quiet=dict(argstr="-quiet",),
        roisel=dict(argstr="-roisel %s", extensions=None,),
        stat=dict(argstr="%s...",),
        zerofill=dict(argstr="-zerofill %s", requires=["num_roi"],),
    )
    inputs = ROIStats.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ROIStats_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = ROIStats.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value
