# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import ParcellationStats


def test_ParcellationStats_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        aseg=dict(extensions=None, mandatory=True,),
        brainmask=dict(extensions=None, mandatory=True,),
        copy_inputs=dict(),
        cortex_label=dict(extensions=None,),
        environ=dict(nohash=True, usedefault=True,),
        hemisphere=dict(argstr="%s", mandatory=True, position=-2,),
        in_annotation=dict(argstr="-a %s", extensions=None, xor=["in_label"],),
        in_cortex=dict(argstr="-cortex %s", extensions=None,),
        in_label=dict(
            argstr="-l %s", extensions=None, xor=["in_annotatoin", "out_color"],
        ),
        lh_pial=dict(extensions=None, mandatory=True,),
        lh_white=dict(extensions=None, mandatory=True,),
        mgz=dict(argstr="-mgz",),
        out_color=dict(
            argstr="-c %s", extensions=None, genfile=True, xor=["in_label"],
        ),
        out_table=dict(
            argstr="-f %s", extensions=None, genfile=True, requires=["tabular_output"],
        ),
        rh_pial=dict(extensions=None, mandatory=True,),
        rh_white=dict(extensions=None, mandatory=True,),
        ribbon=dict(extensions=None, mandatory=True,),
        subject_id=dict(argstr="%s", mandatory=True, position=-3, usedefault=True,),
        subjects_dir=dict(),
        surface=dict(argstr="%s", position=-1,),
        tabular_output=dict(argstr="-b",),
        th3=dict(argstr="-th3", requires=["cortex_label"],),
        thickness=dict(extensions=None, mandatory=True,),
        transform=dict(extensions=None, mandatory=True,),
        wm=dict(extensions=None, mandatory=True,),
    )
    inputs = ParcellationStats.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ParcellationStats_outputs():
    output_map = dict(
        out_color=dict(extensions=None,), out_table=dict(extensions=None,),
    )
    outputs = ParcellationStats.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value
